==> message-facade-2.0.2-20210801.110452-80-sources.jar: com/bizvane/messagefacade/models/vo/MsgTemplateSendConfigVO.java <==
package com.bizvane.messagefacade.models.vo;

import java.util.Date;

public class MsgTemplateSendConfigVO {
    /**
     * id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Long id;

    /**
     * 企业id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Long sysCompanyId;

    /**
     * 品牌id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Long sysBrandId;

    /**
     * 模板类型
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private String templateType;

    /**
     * 配置内容
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private String content;

    /**
     * 修改人id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Long modifiedUserId;

    /**
     * 修改人名称
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private String modifiedUserName;

    /**
     * 修改时间
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Date modifiedDate;

    /**
     * 创建人id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Long createUserId;

    /**
     * 创建人名称
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private String createUserName;

    /**
     * 创建时间
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Date createDate;

    /**
     * 是否有效 0-无效 1-有效
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Boolean valid;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType == null ? null : templateType.trim();
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }
}

==> message-facade-2.0.2-20210803.020600-82-sources.jar: com/bizvane/messagefacade/models/vo/MsgTemplateSendConfigVO.java <==
package com.bizvane.messagefacade.models.vo;

import java.util.Date;

public class MsgTemplateSendConfigVO {
    /**
     * id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    private Long id;

    /**
     * 企业id
     */
    private Long sysCompanyId;

    /**
     * 品牌id
     */
    private Long sysBrandId;

    /**
     * 模板类型
     */
    private String templateType;

    /**
     * 配置内容 {"expirePoint":过期积分,"absPoint":积分绝对值}
     */
    private String content;

    /**
     * 修改人id
     */
    private Long modifiedUserId;

    /**
     * 修改人名称
     */
    private String modifiedUserName;

    /**
     * 修改时间
     */
    private Date modifiedDate;

    /**
     * 创建人id
     */
    private Long createUserId;

    /**
     * 创建人名称
     */
    private String createUserName;

    /**
     * 创建时间
     */
    private Date createDate;

    /**
     * 是否有效 0-无效 1-有效
     */
    private Boolean valid;

    private Integer pageNumber;

    private Integer pageSize;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType == null ? null : templateType.trim();
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}
